plone.app.event.browser.event_view — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.browser.event_view

`plone.app.event.browser.event_view.` `get_location`(context)

  Return the location. This method can be used to be overwritten by external packages, for example to provide a reference to a Location object as done by collective.venue.

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »